Presence - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Presence

A `betty.model.ancestry.Presence` acts as a bridge that links a Person to an Event.

## Fields

Presences inherit from:

- Privacy

`person` (Person)

  The person who was present at `event`.

`event` (Event)

  The event `person` was present at.

`id` (`str`)

  The presence’s own entity ID.

`role` (PresenceRole)

  `person`’s role in the event.